#
# spec file for package howl
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           howl
Version:        0.6
Release:        2.19
Summary:        Editor with keyboard-centric minimalistic interface
License:        MIT
Group:          Productivity/Text/Editors
Url:            https://howl.io/
Source0:        https://github.com/howl-editor/howl/releases/download/%{version}/%{name}-%{version}.tgz
Source1:        howl-rpmlintrc
Patch0:         howl-respect-cflags.patch
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  gtk3-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  update-desktop-files
Requires:       luajit
# Bundled LuaJIT-2.1.0-beta3 failed to compile with this architectures
ExcludeArch:    aarch64 ppc64 ppc64le s390x

%description
Howl is a general purpose editor that is customizable. It is built on
top of the LuaJIT runtime, and can be extended in either Lua or
Moonscript. It has a minimalistic UI, driven mainly using the
keyboard.

%prep
%setup -q
%patch0 -p1
find . -name '*.rb' -exec sed -i "s/#! \/usr\/bin\/env ruby/#!\/usr\/bin\/ruby/" {} +

%build
export CFLAGS="%{optflags}"
cd src
make %{?_smp_mflags}

%install
pushd src
%make_install PREFIX=%{_prefix}
popd

cp -R share/ %{buildroot}%{_prefix}/

%suse_update_desktop_file -r howl Utility TextEditor

%fdupes %{buildroot}%{_prefix}

%files
%license LICENSE.md
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/%{name}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_bindir}/%{name}
%{_bindir}/%{name}-spec

%changelog
* Tue Jun  9 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Exclude architectures unsupported by bundled LuaJIT:
  aarch64 ppc64 ppc64le s390x
* Fri Apr  5 2019 mvetter@suse.com
- Update to 0.6:
  * Added navigate-go-to command, for going back to a specific
    previous location.
  * Added support for a “journal” buffer showing the Howl log,
    available via open-journal.
  * Ensure loaded buffers contain valid UTF-8 at all times
  * Better lexing for C, Rust, Python
  * Added support for specifying line and column when opening files
  * Added support for custom user fonts
  * Added project-switch-buffer command that displays open buffers
    within the current project.
  * Added two inspectors and a command for documentation to the Go mode
  * Moving cursor left or right with a selection active now cancels
    the selection, leaving the cursor at the corresponding end.
  * Added proper structure support for C/C++ mode
  * Base scheme support on the newer lisp mode instead of old basic mode
  * Added the **popup_menu_accept_key option, for controlling which
    key accepts the current option for a popup menu, such as the
    completion popup. Valid values are ‘enter’ (the default) or ‘tab’.
  * Close completion popup when user activity warrants it
  * Added new built-in theme: Dracula
  * Added integrated and fast project file search functionality via
    two new commands: project-file-search and project-file-search-list
  * Javascript: Support for ES6 templates and new keywords and operators
  * Performance and functionality improvements for the matcher, used
    in Howl selection lists, enabling fast matching across much
    larger data sets.
  * Performance improvements for recursive file selection.
    Between 30x and 32x faster.
  * Respect use_tabs option when commenting
  * Ensure scrolling works correctly for Gtk+ 3.4
  * Dart bundle enhancements: improved syntax highlighting
  * Added support for activities - potentially longer running activities
    that should run in a apparently blocking way to the user.
  * Added a new commandline flag, --run-async, for running a particular
    file in a asynchronous Howl context.
  * Added support for shared, low precision after timers
  * Added options for controlling scrolling speed
  * Add support for smooth scrolling events
  * Fixed background drawing for Wayland/Weston/CSD environments.
  * Requested that titlebar is hidden for newer versions of Gnome 3.
  * Added support for navigating back and forth in a list of previously
  visited locations. Two new commands, navigate-back and
  navigate-forward were added, bound to ctrl_< and ctrl_> respectively.
  * Improved key translation for keys when caps lock is on.
  * Added two new commands, editor-newline-above and editor-newline-below,
    that insert a new line above/below the current line. Bound these
    commands to ctrl_shift_return and ctrl_return.
  * Auto detect line endings when opening a file if possible
  * For details see: https://howl.io/blog/2019/04/05/howl-0-6-released.html
- Add howl-rpmlintrc: it only installs an example C file
* Wed Feb 21 2018 tchvatal@suse.com
- Install properly to /usr not /usr/local
- Drop post/postun that is empty on 15+
- Mark license as %%license
- Package bundles lpeg and luajit
* Sun Feb 18 2018 avindra@opensuse.org
- Update to 0.5.3
  * workaround for a Gtk issue with scrollbars.
- includes 0.5.2:
  * Fixed a bug manifesting in a SIGSEGV on OpenBSD.
* Mon Jul 17 2017 jengelh@inai.de
- Make a neutral summary
* Thu Jul 13 2017 tchvatal@suse.com
- Version update to latest 0.5.1 release:
  * Code inspection
  * More bundles
  * Loads of bugfixes
- Remove merged patch appdata.patch
- Add patch to respect cflags howl-respect-cflags.patch
* Wed Feb  8 2017 jengelh@inai.de
- Trim filler words from description
* Sun Jan 29 2017 mailaender@opensuse.org
- add appdata.patch for https://en.opensuse.org/openSUSE:AppStore
* Sat Dec 24 2016 mailaender@opensuse.org
- spec file cleanup
* Wed Nov 16 2016 code@baez.nyc
  Updating to 0.4.1
* Thu Jun  2 2016 code@baez.nyc
  An initial spec of howl.
